@@ -1,14 +1,12 @@
 
 /*
- *	$RCSfile: gui.c,v $	$Revision: 1.13 $ 
- *	$Date: 1997/03/09 16:27:20 $
+ *	$Id: gui.c,v 1.20 1997/05/14 12:52:47 mark Exp $ 
  *
  *	Gui.c : This file well contain most of the user-interface code, 
- *	allowing the compilatio of privtool on different operating systems 
- *	and with UI toolkits by 'simply' replacing the lowest level of 
- *	functionality.
+ *	allowing compilation on different operating systems and other 
+ *	UI toolkits by 'simply' replacing the lowest level of functionality.
  *
- *	(c) Copyright 1993-1996 by Mark Grant, and by other
+ *	(c) Copyright 1993-1997 by Mark Grant, and by other
  *	authors as appropriate. All rights reserved.
  *
  *	The authors assume no liability for damages resulting from the 
@@ -45,6 +43,9 @@
 #ifdef SYSV
 #include <unistd.h>
 #endif
+#ifdef linux
+#include <paths.h>
+#endif
 
 #include "def.h"
 #include "buffers.h"
@@ -65,10 +66,14 @@ static	time_t	last_displayed = 0;
 static	char	*mail_args[] =
 
 {
-#if defined(__FreeBSD__) || defined(linux)
+#if defined(__FreeBSD__)
 	"/usr/sbin/sendmail",
+#else
+#ifdef linux
+	_PATH_SENDMAIL,
 #else
 	"/usr/lib/sendmail",
+#endif
 #endif
 	"-t",
 	NULL
@@ -111,6 +116,24 @@ static	char	*remail_args[32] =
 };
 #endif
 
+#ifndef NO_PREMAIL
+static	char	premail_exec[] = PREMAILEXEC;
+
+static	char	*premail_send_args[3] =
+{
+	premail_exec,
+	"-t",
+	NULL,
+};
+
+static	char	*premail_decode_args[3] =
+{
+	premail_exec,
+	"-decode",
+	NULL,
+};
+#endif
+
 /* Titles for passphrase windows */
 
 static	char	sign_passphrase[]="Passphrase entry (Signing)";
@@ -119,6 +142,7 @@ static	char	decrypt_passphrase[]="Passphrase entry (Decryption)";
 /* Global variables */
 
 char	*passphrase;
+int     show_deleted = 0;
 void	(*callback_proc)();
 COMPOSE_WINDOW	*callback_win;
 
@@ -145,13 +169,11 @@ char	prog_name[] = "XSafeMail";
 char	prog_name[] = "Privtool";
 #endif
 
-char	prog_ver [] = "V0.88 BETA";
+char	prog_ver [] = "V0.89 BETA";
 
 /* Set the description of the message for the message list */
 
-void	set_message_description(m)
-
-MESSAGE	*m;
+void	set_message_description(MESSAGE *m)
 
 {
 	char	mess_desc[256];
@@ -195,11 +217,19 @@ MESSAGE	*m;
 		else
 			mess_type[2] = 'E';
 	}
+	else if (m->flags & MESS_NYM) {
+		mess_type[2] = 'P';
+	}
 
 	/* Create message size string */
 
 	if (layout_compact) {
-		sprintf(mess_desc,"%3.3s %4d %-20.20s %17.16s %4d %-64.64s",
+		sprintf(mess_desc,
+#ifdef MOTIF
+			"%3.3s %4d %-20.20s %17.16s %4d %s",
+#else
+			"%3.3s %4d %-20.20s %17.16s %4d %-64.64s",
+#endif
 			mess_type,m->number,m->email,m->date,
 			m->lines,m->subject ? m->subject : "");
 	}
@@ -374,7 +404,7 @@ MESSAGE	*m;
 
 	/* Put special Digest handling here */
 
-m->flags &= ~(MESS_SIGNED|MESS_ENCRYPTED);
+	    m->flags &= ~(MESS_SIGNED|MESS_ENCRYPTED);
 
 	}
 
@@ -484,7 +514,7 @@ m->flags &= ~(MESS_SIGNED|MESS_ENCRYPTED);
 
 			/* Replace the old message with the decrypted one */
 
-			newm = message_from_message(m);
+			newm = message_from_message(m, NULL);
 			replace_message_with_message(m,newm);
 			last_message_read = newm;
 
@@ -529,6 +559,104 @@ m->flags &= ~(MESS_SIGNED|MESS_ENCRYPTED);
 
 		clear_busy ();
 	}
+
+#ifndef NO_PREMAIL
+	/* Deal with mail to a nym */
+
+	else if (m->flags & MESS_NYM) {
+		BUFFER	*b, *mc, *fm;
+		MESSAGE	*newm;
+
+		/* Use premail to decode a nym message */
+
+		show_busy ();
+		set_display_footer (w, "Decoding nym message.");
+
+		mc = message_contents (m);
+		if (mc) {
+			b = new_buffer ();
+			fm = new_buffer ();
+
+			add_to_buffer (fm, m->header->message,
+				m->header->length);
+			add_to_buffer (fm, "\n", 1);
+			add_to_buffer (fm, mc->message,
+				mc->length);
+
+			if (!run_program (premail_decode_args[0],
+				fm->message, fm->length,
+				premail_decode_args, NULL, b) && 
+				is_mail_message (b)) {
+
+				/* Replace the old message with the decrypted 
+				   one */
+
+				newm = message_from_message(m, b);
+				replace_message_with_message(m, newm);
+				last_message_read = newm;
+
+				newm->status = MSTAT_READ;
+				if (m->status == MSTAT_NONE) {
+					messages.new--;
+					update_message_list();
+				}
+				if (m->status == MSTAT_UNREAD) {
+					messages.unread--;
+					update_message_list();
+				}
+
+				/* Update message list */
+
+				newm -> flags |= MESS_SELECTED;
+				set_message_description(newm);
+				display_message_description(newm);
+
+				/* Then go back round the loop */
+
+				free_message(m);
+				free_buffer (b);
+				free_buffer (fm);
+	
+				display_message(newm);
+	
+#ifndef MOTIF
+				clear_display_footer (w);
+#endif
+				clear_busy ();
+				return;
+			}
+			else {
+				free_buffer (fm);
+				free_buffer (b);
+			}
+		}
+		clear_display_footer (w);
+		clear_busy ();
+
+		goto	display_plaintext;
+	}
+#endif
+
+	else if (m->is_mime)
+	{
+		switch (m->content_transfer_encoding)
+		{
+			case CONTENT_ENCODING_PRINTABLE:
+			{
+				BUFFER *encoded, *decoded;
+				decoded = new_buffer();
+				encoded = message_contents (m);
+				
+				mime_decode_printable(encoded, decoded);
+				display_message_body(decoded, w);
+		
+				free_buffer(decoded);
+			}
+				break;
+			default:
+				goto display_plaintext; /* arrgh my first goto */
+		}
+	}
 	else {
 
 	display_plaintext:
@@ -573,13 +701,15 @@ m->flags &= ~(MESS_SIGNED|MESS_ENCRYPTED);
 
 	/* Clear the footer now it's displayed */
 
+#ifndef MOTIF
 	clear_display_footer(w);
+#endif
 	clear_main_footer ();
 }
 
 /* Selecting next or previous message */
 
-static	void	select_message_proc(m)
+void	select_message_proc(m)
 
 MESSAGE	*m;
 
@@ -832,9 +962,10 @@ MESSAGE	*om;
 	}
 
 	/* Clear selected flag */
-
-	om->flags &= ~MESS_SELECTED;
-	om->list_pos = (-1);
+	if(!show_deleted){
+	    om->flags &= ~MESS_SELECTED;
+	    om->list_pos = (-1);
+	}
 
 	/* Update message info */
 
@@ -882,6 +1013,7 @@ void	decrypt_with_passphrase()
 
 {
 	display_message(message_to_decrypt);
+	sync_list();
 }
 
 void	set_flags_from_decryption(m,i)
@@ -1563,7 +1695,7 @@ try_again:
 				add_list_to_header (mail_message, bcc_addrs);
 			}
 #if 0
-			if (strcmp(nym, our_userid) {
+			if (strcmp(nym, our_userid)) {
 				add_to_buffer (mail_message, "From: ", 6);
 				add_to_buffer (mail_message, nym, strlen(nym));
 			}
@@ -1839,7 +1971,7 @@ void	load_new_mail()
 		i = last->number;
 		mm = last;
 
-		while (mm && (mm->flags & MESS_DELETED)) {
+		while (mm && (mm->flags & MESS_DELETED) && ! show_deleted) {
 			mm = mm->prev;
 		}
 
@@ -1857,7 +1989,7 @@ void	load_new_mail()
 
 	while (m) {
 		m->number = ++i;
-		if (!(m->flags & MESS_DELETED))
+		if (!(m->flags & MESS_DELETED) || show_deleted)
 			m->list_pos = ++l;
 
 		set_message_description (m);
@@ -1993,10 +2125,13 @@ void	inbox_proc()
 	update_random();
 
 	show_busy ();
-	if (reading_file (default_mail_file))
-		load_new_mail ();
-	else
-		load_file_proc (default_mail_file);
+	if (reading_file (default_mail_file)){
+	    load_new_mail ();
+	}
+	else{
+	    deleteAllMessages();
+	    load_file_proc (default_mail_file);
+	}
 
 	clear_busy();
 }
@@ -2124,7 +2259,7 @@ int	(*proc)();
 			m_list[i]->next = m_list[i+1];
 		}
 
-		if (!(m_list[i]->flags & MESS_DELETED)) {
+		if (!(m_list[i]->flags & MESS_DELETED) || show_deleted) {
 			m_list[i]->list_pos = l++;
 			set_message_description (m_list[i]);
 			display_message_description (m_list[i]);
@@ -2197,10 +2332,20 @@ void	undelete_last_proc ()
 		deleted.start = m->dnext;
 	}
 
-	/* Clear deleted list stuff */
+	undelete(m);
+}
 
-	m->dnext = m->dprev = NULL;
-	m->flags &= ~MESS_DELETED;
+void
+undelete(MESSAGE *m)
+{
+    MESSAGE	*p;
+    int		l;
+
+    if(! (m->flags |= MESS_DELETED))
+	return;
+
+    m->dnext = m->dprev = NULL;
+    m->flags &= ~MESS_DELETED;
 
 	deleted.number--;
 	messages.number++;
@@ -2235,7 +2380,8 @@ void	undelete_last_proc ()
 	}
 
 	update_message_list ();
-}
+	sync_list();
+} /* undelete */
 
 static	char	dec_mess [] = "Decrypted message reads :\n\n";
 static	char	sig_mess [] = "\n\nMessage was signed :\n\n";
@@ -2494,3 +2640,65 @@ BUFFER	*b;
 	return FALSE;
 }
 
+
+int mime_decode_printable(BUFFER *encoded, BUFFER *decoded)
+{
+	char *from;
+	int len, i;
+	
+	/* be paranoid */
+	if (!encoded || !decoded)
+		return 0;
+
+	from = encoded->message;
+	len = encoded->length;
+	
+	for (i = 0; i < len; i++)
+	{
+		if (from[i] != '=')
+		{
+			/* copy all chars that are not '=' */
+			add_to_buffer(decoded, from+i, 1);
+			continue;
+		}
+		
+		/* decode rfc1341 says "=0A" is linefeed; "=20" is space blabla */
+		if (++i < len)
+		{
+			char hex[2];
+			unsigned char val;
+			
+			if (from[i] == '\n')
+			{
+				/* ignore softline break */
+				continue;
+			}
+			else
+				/* get the first hex char */
+				hex[0] = toupper(from[i]);
+
+			/* get the second hex char */				
+			if (++i < len)
+				hex[1] = toupper(from[i]);
+			else
+				continue;
+
+			/* wow turn hex to decimal */
+			if (isdigit(hex[0]))
+				val = 16 * (hex[0] - '0');
+			else
+				val = 16 * (hex[0] - 'A' + 10);
+		
+			if (isdigit(hex[1]))
+				val += (hex[1] - '0');
+			else
+				val += (hex[1] - 'A' + 10);
+			
+
+			/* and add the poor mans decoded value to the buffer */
+			add_to_buffer(decoded, &val, 1);
+		}
+	}
+
+	return 1;
+}
