@@ -1,7 +1,6 @@
 
 /*
- *	$RCSfile: pgplib.c,v $	$Revision: 1.18 $ 
- *	$Date: 1997/03/09 16:27:20 $
+ *	$Id: pgplib.c,v 1.24 1997/04/27 19:18:11 mark Exp $ 
  *
  *	pgplib.c, (mostly) by Mark Grant 1993-1997
  *
@@ -54,6 +53,13 @@
 #include <sys/timeb.h>
 #include <sys/resource.h>
 #include <ctype.h>
+#ifdef GDBM
+#include <gdbm.h>
+#endif
+#ifdef BDB
+#include <fcntl.h>
+#include <db.h>
+#endif
 
 #include "def.h"
 
@@ -639,6 +645,13 @@ void	reseed_random (void)
 #endif
 }
 
+#ifdef GDBM
+static	GDBM_FILE	keyfile = 0;
+#endif
+#ifdef BDB
+static	DB	*keyfile;
+#endif
+
 /* Find a public key, given the userid */
 
 static	int	get_public_key (byte *id, byte *userid, struct pgp_pubkey *key, 
@@ -651,6 +664,12 @@ static	int	get_public_key (byte *id, byte *userid, struct pgp_pubkey *key,
 	int	revoked;
 	int	found = FALSE;
 	byte	our_uid [256];
+#ifdef GDBM
+	datum	data, idkey;
+#endif
+#ifdef BDB
+	DBT	data, idkey;
+#endif
 
 	/* First check the hash table */
 
@@ -659,6 +678,54 @@ static	int	get_public_key (byte *id, byte *userid, struct pgp_pubkey *key,
 		return TRUE;
 #endif
 
+#if defined(GDBM) || defined (BDB)
+	if (!keyfile) {
+		char	file[PATH_MAX];
+		char	*pgpp;
+
+		pgpp = getenv ("PGPPATH");
+		if (pgpp) {
+#ifdef GDBM
+			sprintf (file, "%s/pubring.dbm", pgpp);
+			keyfile = gdbm_open (file, 512, GDBM_READER, 
+				0600, 0);
+#else
+			sprintf (file, "%s/pubring.db", pgpp);
+			keyfile = dbopen (file, O_RDONLY, 0600,
+				DB_HASH, NULL);
+#endif
+		}
+	}
+	if (keyfile) {
+#ifdef GDBM
+		idkey.dptr = id;
+		idkey.dsize = 8;
+		data = gdbm_fetch (keyfile, idkey);
+
+		if (data.dptr) {
+			memcpy (key, data.dptr, sizeof (*key));
+			strcpy (userid, data.dptr + sizeof (*key));
+			*trust = data.dptr [sizeof (*key) + 
+				strlen (userid) + 2];
+			return TRUE;
+		}
+#else
+		idkey.data = id;
+		idkey.size = 8;
+		found = (keyfile->get (keyfile, &idkey, &data, 0) >= 0);
+
+		if (found && data.data) {
+			byte	*p = (byte *)data.data;
+
+			memcpy (key, p, sizeof (*key));
+			strcpy (userid, p + sizeof (*key));
+			*trust = p [sizeof (*key) + strlen (userid) + 2];
+			return TRUE;
+		}
+#endif
+	}
+#endif
+
 	/* Oh well, now for the hard work */
 
 	/* First check smallring.pgp in case it's a common key */
@@ -1444,6 +1511,17 @@ void	close_pgplib(void)
 #if defined(USE_FLOPPY) && defined(AUTO_EJECT)
 	eject_floppy();
 #endif
+
+#if defined(GDBM) || defined (BDB)
+	if (keyfile) {
+#ifdef GDBM
+		gdbm_close (keyfile);
+#else
+		keyfile->close (keyfile);
+#endif
+		keyfile = 0;
+	}
+#endif
 }
 
 /* Routines to deal with running other programs, such as PGP */
@@ -1783,6 +1861,7 @@ static	char	*filter_argv[]={
 	"pgp",
 	"-f",
 	"+batchmode",
+	"+language=en",
 	NULL
 };
 
@@ -2444,14 +2523,34 @@ int	encrypt_message(char **user, BUFFER *message, BUFFER *encrypted,
 		   probably already know the message text. */
 
 		do {
+
+			/* Start with values from /dev/random if we have
+			   it */
+#ifdef DEV_RANDOM
+			int	fd;
+			int	cnt = IDEA_KEY_SIZE;
+			int	rdsz;
+#endif
+
 			good_key = 0;
 
+#ifdef DEV_RANDOM
+			fd = open ("/dev/random", O_RDONLY);
+			if (fd >= 0) {
+				while (cnt > 0 && 
+					(rdsz = read (fd, key + (IDEA_KEY_SIZE - cnt), cnt)) >= 0) {
+					cnt -= rdsz;
+				}
+				close (fd);
+			}
+#endif
+
 			/* We look for a good key by checking for the
 			   zero nibbles in a weak key. If any of these
 			   nibbles are non-zero then we have a good key. */
 			   
 			for (i = 0; i < IDEA_KEY_SIZE; i++) {
-				key [i] = our_randombyte() ^ mess_md5[i];
+				key [i] ^= our_randombyte() ^ mess_md5[i];
 				good_key |= (key[i] & idea_weak_key_mask[i]);
 			}
 
@@ -2837,7 +2936,10 @@ int	encrypt_message(char **user, BUFFER *message, BUFFER *encrypted,
 		}
 	}
 
+	/* Use batchmode and set language to english when we run. */
+
 	argv[arg++]="+batchmode";
+	argv[arg++]="+language=en";
 
 	/* We now need to add the list of users. If we overrun the
 	   allocated array we'll have to extend it. */
